.. _curp_class:

Referencia de API
=================


CURP
----

.. autoclass:: curp.CURP
  :inherited-members:

Excepciones
-----------

.. autoexception:: curp.CURPValueError
.. autoexception:: curp.CURPLengthError
.. autoexception:: curp.CURPVerificationError
.. autoexception:: curp.CURPNameError
.. autoexception:: curp.CURPFirstSurnameError
.. autoexception:: curp.CURPSecondSurnameError
.. autoexception:: curp.CURPFullNameError
.. autoexception:: curp.CURPDateError
.. autoexception:: curp.CURPSexError
.. autoexception:: curp.CURPRegionError
